@@ -3,4 +3,4 @@ from .recipes import Recipe  # noqa: F401
 from .recipes import uninstall  # noqa: F401
 
 
-__author__ = 'Md Nazrul Islam<connect2nazrul@gmail.com>'
+__author__ = "Md Nazrul Islam<connect2nazrul@gmail.com>"
